@@ -7,7 +7,6 @@ import gettext
 import ConfigParser
 import grp
 import locale
-import apt
 import tempfile
 import thread
 import subprocess
@@ -20,6 +19,11 @@ from gi.repository import Gtk, GObject, Gio, AccountsService, GLib, GdkPixbuf
 
 from ImConfig.ImConfig import ImConfig
 
+# Used to detect Debian derivatives (we don't want to show APT features in other distros)
+IS_DEBIAN = os.path.exists("/etc/debian_version")
+
+if IS_DEBIAN:
+    import apt
 
 # i18n
 APP = 'mintlocale'
@@ -120,7 +124,6 @@ class Locale():
         self.id = id
         self.name = name
 
-
 class PictureChooserButton (Gtk.Button):
 
     def __init__(self, num_cols=4, button_picture_size=None, menu_pictures_size=None, has_button_label=False):
@@ -389,8 +392,17 @@ class MintLocale:
 
     def __init__(self, show_input_methods):
 
+        # Determine path to system locale-config
+        self.locale_path=''
+
+        if os.path.exists('/etc/default/locale'):
+            self.locale_path='/etc/default/locale'
+        else:
+            self.locale_path='/etc/locale.conf'
+
         # Prepare the APT cache
-        self.cache = apt.Cache()
+        if IS_DEBIAN:
+            self.cache = apt.Cache()
         self.cache_updated = False
 
         # load our glade ui file in
@@ -405,9 +417,9 @@ class MintLocale:
         # set up larger components.
         self.builder.get_object("main_window").set_title(_("Language Settings"))
 
-        toolbar = Gtk.Toolbar()
-        toolbar.get_style_context().add_class("primary-toolbar")
-        self.builder.get_object("box1").pack_start(toolbar, False, False, 0)
+        self.toolbar = Gtk.Toolbar()
+        self.toolbar.get_style_context().add_class("primary-toolbar")
+        self.builder.get_object("box1").pack_start(self.toolbar, False, False, 0)
 
         stack = Gtk.Stack()
         stack.set_transition_type(Gtk.StackTransitionType.SLIDE_LEFT_RIGHT)
@@ -420,13 +432,13 @@ class MintLocale:
         tool_item = Gtk.ToolItem()
         tool_item.set_expand(True)
         tool_item.get_style_context().add_class("raised")
-        toolbar.insert(tool_item, 0)
+        self.toolbar.insert(tool_item, 0)
         switch_holder = Gtk.Box(orientation=Gtk.Orientation.HORIZONTAL)
         switch_holder.set_border_width(1)
         tool_item.add(switch_holder)
         switch_holder.pack_start(stack_switcher, True, True, 0)
         stack_switcher.set_halign(Gtk.Align.CENTER)
-        toolbar.show_all()
+        self.toolbar.show_all()
 
         size_group = Gtk.SizeGroup.new(Gtk.SizeGroupMode.HORIZONTAL)
 
@@ -469,7 +481,8 @@ class MintLocale:
 
         self.install_row = SettingsRow(self.install_label, self.locale_install_button)
         self.install_row.set_no_show_all(True)
-        language_settings.add_row(self.install_row)
+        if IS_DEBIAN:
+            language_settings.add_row(self.install_row)
 
         page = SettingsPage()
         stack.add_titled(page, "input settings", _("Input method"))
@@ -506,12 +519,12 @@ class MintLocale:
         row = SettingsRow(label, self.im_combo)
         self.input_settings.add_row(row)
 
-        self.input_settings = page.add_section(_("Language support"))
-
-        for im_language in self.im_languages:
-            size_group.add_widget(im_language.button)
-            size_group.add_widget(im_language.installed_label)
-            self.input_settings.add_row(im_language.settings_row)
+        if IS_DEBIAN:
+            self.input_settings = page.add_section(_("Language support"))
+            for im_language in self.im_languages:
+                size_group.add_widget(im_language.button)
+                size_group.add_widget(im_language.installed_label)
+                self.input_settings.add_row(im_language.settings_row)
 
         self.im_loaded = False  # don't react to im changes until we're fully loaded (we're loading that combo asynchronously)
         self.im_combo.connect("changed", self.on_combobox_input_method_changed)
@@ -573,7 +586,7 @@ class MintLocale:
         groups = grp.getgrall()
         for group in groups:
             (name, pw, gid, mem) = group
-            if name in ("adm", "sudo"):
+            if name in ("adm", "sudo", "wheel", "root"):
                 for user in mem:
                     if current_user == user:
                         self.system_row.set_no_show_all(False)
@@ -590,7 +603,7 @@ class MintLocale:
 
     def button_system_language_clicked(self, button):
         print "Setting system locale: language '%s', region '%s'" % (self.current_language, self.current_region)
-        subprocess.call(['gksu', 'set-default-locale', self.current_language, self.current_region])
+        subprocess.call(['gksu', 'set-default-locale', self.locale_path, self.current_language, self.current_region])
         self.set_system_locale()
         pass
 
@@ -603,6 +616,7 @@ class MintLocale:
     def check_input_methods(self):
         if not self.ImConfig.available():
             self.im_combo.set_sensitive(False)
+            self.toolbar.hide()
             return
 
         if not self.im_combo.get_model():
@@ -675,9 +689,9 @@ class MintLocale:
         region_str = _("No locale defined")
 
         # Get system locale
-        if os.path.exists("/etc/default/locale"):
+        if os.path.exists(self.locale_path):
             vars = dict()
-            with open("/etc/default/locale") as f:
+            with open(self.locale_path) as f:
                 for line in f:
                     eq_index = line.find('=')
                     var_name = line[:eq_index].strip()
@@ -866,16 +880,11 @@ class MintLocale:
             self.dmrc.write(configfile)
         os.system("sed -i 's/ = /=/g' %s" % self.dmrc_path)  # Remove space characters around "="" sign, created by ConfigParser
 
-        # Set it in .pam_environment
-        if os.path.exists(self.pam_environment_path):
-            for lc_variable in ['LANGUAGE', 'LANG']:
-                os.system("sed -i '/^%s=.*/d' %s" % (lc_variable, self.pam_environment_path))
-            for lc_variable in ['LC_TIME']:
-                os.system("sed -i 's/^%s=.*/%s=%s/g' %s" % (lc_variable, lc_variable, locale.id, self.pam_environment_path))
-        else:
-            os.system("sed -e 's/$locale/%s/g' -e 's/$region/%s/g' /usr/share/linuxmint/mintlocale/templates/default_pam_environment.template > %s" % (locale.id, self.current_region, self.pam_environment_path))
-
         self.current_language = locale.id
+
+        # Set it in .pam_environment
+        self.set_pam_environment()
+
         self.locale_system_wide_button.set_sensitive(True)
 
         return True
@@ -889,18 +898,62 @@ class MintLocale:
         # Second, it's Ubuntu specific...
         # Third it overwrites LC_TIME in .pam_environment
 
-        # Set it in .pam_environment
-        if os.path.exists(self.pam_environment_path):
-            for lc_variable in ['LC_NUMERIC', 'LC_MONETARY', 'LC_PAPER', 'LC_NAME', 'LC_ADDRESS', 'LC_TELEPHONE', 'LC_MEASUREMENT', 'LC_IDENTIFICATION']:
-                os.system("sed -i 's/^%s=.*/%s=%s/g' %s" % (lc_variable, lc_variable, locale.id, self.pam_environment_path))
-        else:
-            os.system("sed -e 's/$locale/%s/g' -e 's/$region/%s/g' /usr/share/linuxmint/mintlocale/templates/default_pam_environment.template > %s" % (self.current_language, locale.id, self.pam_environment_path))
-
         self.current_region = locale.id
+
+        # Set it in .pam_environment
+        self.set_pam_environment()
+
         self.locale_system_wide_button.set_sensitive(True)
 
         return True
 
+    def set_pam_environment(self):
+        shortlocale = self.current_language
+        if "." in self.current_language:
+            shortlocale = self.current_language.split(".")[0]
+
+        if os.path.exists(self.pam_environment_path):
+
+            # Replace values for present fields
+            for lc_variable in ['LC_NUMERIC', 'LC_MONETARY', 'LC_PAPER', 'LC_NAME', 'LC_ADDRESS', 'LC_TELEPHONE', 'LC_MEASUREMENT', 'LC_IDENTIFICATION']:
+                os.system("sed -i 's/^%s=.*/%s=%s/g' %s" % (lc_variable, lc_variable, self.current_region, self.pam_environment_path))
+            for lc_variable in ['LC_TIME', 'LANG']:
+                os.system("sed -i 's/^%s=.*/%s=%s/g' %s" % (lc_variable, lc_variable, self.current_language, self.pam_environment_path))
+            for lc_variable in ['LANGUAGE']:
+                os.system("sed -i 's/^%s=.*/%s=%s/g' %s" % (lc_variable, lc_variable, shortlocale, self.pam_environment_path))
+
+            # Check missing fields
+            with open(self.pam_environment_path, 'r') as file:
+                content = file.read()
+
+            for lc_variable in ['LC_NUMERIC', 'LC_MONETARY', 'LC_PAPER', 'LC_NAME', 'LC_ADDRESS', 'LC_TELEPHONE', 'LC_MEASUREMENT', 'LC_IDENTIFICATION']:
+                if not (("%s=" % lc_variable) in content or ("%s =" % lc_variable) in content):
+                    os.system("echo '%s=%s' >> %s" % (lc_variable, self.current_region, self.pam_environment_path))
+            if not ("LC_TIME=" in content or "LC_TIME =" in content):
+                os.system("echo 'LC_TIME=%s' >> %s" % (self.current_language, self.pam_environment_path))
+
+            if ("XDG_SEAT_PATH" in os.environ):
+                # LightDM
+                if not ("PAPERSIZE=" in content or "PAPERSIZE =" in content):
+                    os.system("echo 'PAPERSIZE=a4' >> %s" % self.pam_environment_path)
+                if not ("LANGUAGE=" in content or "LANGUAGE =" in content):
+                    os.system("echo 'LANGUAGE=%s' >> %s" % (shortlocale, self.pam_environment_path))
+                if not ("LANG=" in content or "LANG =" in content):
+                    os.system("echo 'LANG=%s' >> %s" % (self.current_language, self.pam_environment_path))
+            else:
+                # MDM
+                for lc_variable in ['LANGUAGE', 'LANG']:
+                    os.system("sed -i '/^%s=.*/d' %s" % (lc_variable, self.pam_environment_path))
+
+        else:
+            if ("XDG_SEAT_PATH" in os.environ):
+                # LightDM
+                os.system("sed -e 's/$locale/%s/g' -e 's/$shortlocale/%s/g' -e 's/$region/%s/g' /usr/share/linuxmint/mintlocale/templates/lightdm_pam_environment.template > %s" % (self.current_language, shortlocale, self.current_region, self.pam_environment_path))
+            else:
+                # MDM
+                os.system("sed -e 's/$locale/%s/g' -e 's/$region/%s/g' /usr/share/linuxmint/mintlocale/templates/mdm_pam_environment.template > %s" % (self.current_language, self.current_region, self.pam_environment_path))
+
+
 if __name__ == "__main__":
 
     if len(sys.argv) > 1 and sys.argv[1] == "im":
